#' @importFrom dplyr add_count
#' @export
dplyr::add_count

#' @importFrom dplyr arrange
#' @export
dplyr::arrange

#' @importFrom dplyr collect
#' @export
dplyr::collect

#' @importFrom dplyr compute
#' @export
dplyr::compute

#' @importFrom dplyr collapse
#' @export
dplyr::collapse

#' @importFrom dplyr count
#' @export
dplyr::count

#' @importFrom dplyr distinct
#' @export
dplyr::distinct

#' @importFrom dplyr filter
#' @export
dplyr::filter

#' @importFrom dplyr glimpse
#' @export
dplyr::glimpse

#' @importFrom dplyr group_by
#' @export
dplyr::group_by

#' @importFrom dplyr select
#' @export
dplyr::select

#' @importFrom dplyr slice_head
#' @export
dplyr::slice_head

#' @importFrom graphics identify
#' @export
graphics::identify

#' @importFrom sf st_crop
#' @export
sf::st_crop